pub struct OwnedValuePath {
pub segments: Vec<OwnedSegment>,
}Expand description
A lookup path.
Fields
segments: Vec<OwnedSegment>Implementations
Sourceimpl OwnedValuePath
impl OwnedValuePath
pub fn is_root(&self) -> bool
pub fn root() -> Self
pub fn push_field(&mut self, field: &str)
pub fn push_segment(&mut self, segment: OwnedSegment)
pub fn push_front_field(&mut self, field: &str)
pub fn push_front_segment(&mut self, segment: OwnedSegment)
pub fn with_field_appended(&self, field: &str) -> Self
pub fn with_field_prefix(&self, field: &str) -> Self
pub fn with_segment_prefix(&self, segment: OwnedSegment) -> Self
pub fn push_index(&mut self, index: isize)
pub fn with_index_appended(&self, index: isize) -> Self
pub fn single_field(field: &str) -> Self
Sourcepub fn to_alternative_components(&self, limit: usize) -> Option<Vec<&str>>
pub fn to_alternative_components(&self, limit: usize) -> Option<Vec<&str>>
Create the possible fields that can be followed by this lookup.
The limit specifies the limit of the path depth we are interested in. Metrics is only interested in fields that are up to 3 levels deep (2 levels + 1 to check it terminates).
eg, .tags.nork.noog will never be an accepted path so we don’t need to spend the time collecting it.
pub fn push(&mut self, segment: OwnedSegment)